@@ -11,8 +11,10 @@ describe 'neutron::db' do
         :connection     => 'sqlite:////var/lib/neutron/ovs.sqlite',
         :idle_timeout   => '<SERVICE DEFAULT>',
         :min_pool_size  => '<SERVICE DEFAULT>',
+        :max_pool_size  => '<SERVICE DEFAULT>',
         :max_retries    => '<SERVICE DEFAULT>',
         :retry_interval => '<SERVICE DEFAULT>',
+        :max_overflow   => '<SERVICE DEFAULT>',
       )}
 
     end
@@ -22,9 +24,12 @@ describe 'neutron::db' do
         { :database_connection     => 'mysql+pymysql://neutron:neutron@localhost/neutron',
           :database_idle_timeout   => '3601',
           :database_min_pool_size  => '2',
+          :database_max_pool_size  => '11',
           :database_max_retries    => '11',
           :database_retry_interval => '11',
-          :database_db_max_retries => '-1', }
+          :database_db_max_retries => '-1',
+          :database_max_overflow   => '21',
+        }
       end
 
       it { is_expected.to contain_oslo__db('neutron_config').with(
@@ -32,8 +37,10 @@ describe 'neutron::db' do
         :connection     => 'mysql+pymysql://neutron:neutron@localhost/neutron',
         :idle_timeout   => '3601',
         :min_pool_size  => '2',
+        :max_pool_size  => '11',
         :max_retries    => '11',
         :retry_interval => '11',
+        :max_overflow   => '21',
       )}
 
     end
@@ -93,7 +100,7 @@ describe 'neutron::db' do
         { :database_connection => 'mysql+pymysql://neutron:neutron@localhost/neutron' }
       end
 
-      it { is_expected.to contain_package('db_backend_package').with({ :ensure => 'present', :name => 'python-pymysql' }) }
+      it { is_expected.to contain_package('python-pymysql').with({ :ensure => 'present', :name => 'python-pymysql' }) }
     end
 
   end
@@ -113,7 +120,6 @@ describe 'neutron::db' do
         { :database_connection => 'mysql+pymysql://neutron:neutron@localhost/neutron' }
       end
 
-      it { is_expected.not_to contain_package('db_backend_package') }
     end
 
   end
